import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/parameter/clients";

import { h } from "vue";
import dayjs from "dayjs";
import { httpAdd, httpStatus, httpUpdate } from "/@/api/parameter/tagManage";
import { statusList } from "/@/utils/status";
import { userGroupProps, shareTypes } from "./configs";
import { ElTag } from "element-plus";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "菜单数据",
    prop: userGroupProps.menu
  },
  {
    label: "数据源用户",
    width: 130,
    prop: userGroupProps.source_user
  },
  {
    label: "数据源用户组",
    width: 130,
    prop: userGroupProps.source_group
  },
  {
    label: "数据共享用户",
    width: 130,
    prop: userGroupProps.data_user
  },
  {
    label: "数据共享用户组",
    width: 130,
    prop: userGroupProps.data_group
  },
  {
    label: "状态",
    prop: userGroupProps.status,
    cellRenderer({ row }) {
      return h(
        ElTag,
        {
          type: row[userGroupProps.status] === "0" ? "warning" : ""
        },
        {
          default: () =>
            statusList.find(t => t.value === row[userGroupProps.status])
              ?.label || "--"
        }
      );
    }
  },
  {
    label: "共享权限",
    prop: userGroupProps.share,
    cellRenderer({ row }) {
      return h(ElTag, null, {
        default: () =>
          shareTypes.find(t => t.value === row[userGroupProps.share])?.label ||
          "--"
      });
    }
  },
  {
    label: "创建时间",
    prop: "addTime",
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    width: 120,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "数据共享",
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"],
  columns,
  mockData: [
    {
      menu: "采购付款回票", //菜单数据
      source_user: "一个数据源用户", //数据源用户
      source_group: "一个数据源用户组", //数据源用户组
      data_user: "一个数据共享用户", //数据共享用户
      data_group: "一个数据共享用户组", //数据共享用户组
      share: "1", //共享权限
      status: "0" //状态
    }
  ],
  apis: {
    httpList,
    httpStatus,
    httpUpdate,
    httpAdd
  }
};

export default contentConfig;
