import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/parameter/clients";

import { h } from "vue";
import dayjs from "dayjs";
import { httpAdd, httpStatus, httpUpdate } from "/@/api/parameter/tagManage";
import { statusList } from "/@/utils/status";
import { userGroupProps, shareTypes } from "./configs";
import { ElTag } from "element-plus";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "组名称",
    prop: userGroupProps.name
  },
  {
    label: "组成员",
    prop: userGroupProps.user
  },
  {
    label: "状态",
    prop: userGroupProps.status,
    cellRenderer({ row }) {
      return h(ElTag, null, {
        default: () =>
          statusList.find(t => t.value === row[userGroupProps.status])?.label ||
          "--"
      });
    }
  },
  {
    label: "共享类型",
    prop: userGroupProps.type,
    cellRenderer({ row }) {
      return h(ElTag, null, {
        default: () =>
          shareTypes.find(t => t.value === row[userGroupProps.type])?.label ||
          "--"
      });
    }
  },
  {
    label: "备注",
    prop: userGroupProps.remark
  },
  {
    label: "创建时间",
    prop: "addTime",
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    width: 120,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "用户组",
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"],
  columns,
  mockData: [
    {
      name: "一个组", //组名称
      users: "一个人,两个人,三个人", //组成员
      type: "0", //共享类型
      remark: "remark", //备注
      status: "1" //状态
    }
  ],
  apis: {
    httpList,
    httpStatus,
    httpUpdate,
    httpAdd
  }
};

export default contentConfig;
